@@ -14,7 +14,7 @@ if(devel) {
   data(example.ped)
   data(example.geno)
   data(example.map)
-  
+  data(example.relation)
 }
 
 #require(survery)
@@ -54,6 +54,18 @@ print.pedgene(pg.out.m2,digits=3)
 ## AA   AA     1        80.1       0.404        4.90     0.02692
 ## AX   AX     X       198.2       0.186        7.82     0.00515
 
+## with twins
+example.ped[10,"sex"] <- 2
+#example.relation[2,4] <- 1
+#colnames(example.relation) <- c("ped","id1","id2", "code")
+#data(example.relation)
+#example.relation
+pg.out.m2.twins <- pedgene(ped=example.ped, geno=example.geno, relation=example.relation,
+           map=example.map, male.dose=2,  weights.mb=TRUE, checkpeds=TRUE)
+
+# summary/print and plot methods for this object
+print.pedgene(pg.out.m2.twins,digits=3)
+
 ## base case, beta weights, no pedcheck
 pg.beta.m2 <- pedgene(ped=example.ped, geno=example.geno, map=example.map, male.dose=2, verbose.return=TRUE)
 names(pg.beta.m2)
@@ -67,13 +79,16 @@ print(pg.kounen.m2,digits=4)
 
 ## try making ped1 disconeeded by taking 2nd-generation parents away
 ## results will differ a little
-pg.out.m2.rm34 <- pedgene(example.ped[-(3:4),], example.geno, example.map, male.dose=2, checkpeds=FALSE, weights.mb=TRUE)
-pg.out.m2.rm34
+pednew <- example.ped
+pednew$father[with(pednew, famid %in% 1 & father %in% 4)] <- 0
+pednew$mother[with(pednew, famid %in% 1 & mother %in% 3)] <- 0
+pg.out.m2.disconn <- pedgene(pednew, example.geno, example.map, male.dose=2, checkpeds=FALSE, weights.mb=TRUE)
+pg.out.m2.disconn
 
 ## Test character ids, which is robust now because we're now making super-ids by
 ## pasting ped-person together within the function
 options(stringsAsFactors=FALSE)
-char.ped <- with(example.ped, data.frame(ped=as.character(ped), person=as.character(person), father=as.character(father), mother=as.character(mother), sex=sex, trait=trait))
+char.ped <- with(example.ped, data.frame(famid=as.character(famid), person=as.character(person), father=as.character(father), mother=as.character(mother), sex=sex, trait=trait))
 options(stringsAsFactors=TRUE)
 
 ## as long as subject and ped ids are character, not factor, this will work
